@@ -1,16 +1,15 @@
 """
 Type annotations for sso-oidc service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html)
 
 Usage::
 
     ```python
-    from boto3.session import Session
-    from mypy_boto3_sso_oidc.client import SSOOIDCClient
+    import boto3
+    from mypy_boto3_sso_oidc import SSOOIDCClient
 
-    session = Session()
-    client: SSOOIDCClient = session.client("sso-oidc")
+    client: SSOOIDCClient = boto3.client("sso-oidc")
     ```
 """
 from typing import Any, Dict, Mapping, Sequence, Type
@@ -52,8 +51,8 @@ class Exceptions:
 
 class SSOOIDCClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client/)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/sso-oidc.html#SSOOIDC.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html)
     """
 
     meta: ClientMeta
@@ -62,17 +61,14 @@ class SSOOIDCClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         SSOOIDCClient exceptions.
-
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client/#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client/#can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#can_paginate)
         """
 
     def create_token(
@@ -90,8 +86,8 @@ class SSOOIDCClient(BaseClient):
         """
         Creates and returns an access token for the authorized client.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client/#create_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#create_token)
         """
 
     def generate_presigned_url(
@@ -104,8 +100,8 @@ class SSOOIDCClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client/#generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#generate_presigned_url)
         """
 
     def register_client(
@@ -114,8 +110,8 @@ class SSOOIDCClient(BaseClient):
         """
         Registers a client with AWS SSO.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client/#register_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#register_client)
         """
 
     def start_device_authorization(
@@ -125,6 +121,6 @@ class SSOOIDCClient(BaseClient):
         Initiates device authorization by requesting a pair of verification codes from
         the authorization service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client/#start_device_authorization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#start_device_authorization)
         """
